@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::DistManifest;
 # ABSTRACT: Release tests for the manifest
-our $VERSION = '2.0.1'; # VERSION
+our $VERSION = '2.000002'; # VERSION
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 
@@ -25,7 +25,7 @@ Dist::Zilla::Plugin::Test::DistManifest - Release tests for the manifest
 
 =head1 VERSION
 
-version 2.0.1
+version 2.000002
 
 =head1 SYNOPSIS
 
@@ -49,12 +49,7 @@ The project homepage is L<http://metacpan.org/release/Dist-Zilla-Plugin-Test-Dis
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you, or see L<http://search.cpan.org/dist/Dist-Zilla-Plugin-Test-DistManifest/>.
-
-The development version lives at L<http://github.com/doherty/Dist-Zilla-Plugin-Test-DistManifest>
-and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-Test-DistManifest.git>.
-Instead of sending patches, please fork this project using the standard
-git and github infrastructure.
+site near you, or see L<https://metacpan.org/module/Dist::Zilla::Plugin::Test::DistManifest/>.
 
 =head1 SOURCE
 
@@ -63,10 +58,8 @@ and may be cloned from L<git://github.com/doherty/Dist-Zilla-Plugin-Test-DistMan
 
 =head1 BUGS AND LIMITATIONS
 
-No bugs have been reported.
-
-Please report any bugs or feature requests through the web interface at
-L<https://github.com/doherty/Dist-Zilla-Plugin-Test-DistManifest/issues>.
+You can make new bug reports, and view existing ones, through the
+web interface at L<https://github.com/doherty/Dist-Zilla-Plugin-Test-DistManifest/issues>.
 
 =head1 AUTHORS
 
